@@ -32,10 +32,10 @@ from oslo_policy import policy
 from oslo_policy.tests import base
 
 
-POLICY_A_CONTENTS = jsonutils.dumps({"default": "role:fakeA"})
-POLICY_B_CONTENTS = jsonutils.dumps({"default": "role:fakeB"})
-POLICY_FAKE_CONTENTS = jsonutils.dumps({"default": "role:fakeC"})
-POLICY_JSON_CONTENTS = jsonutils.dumps({
+POLICY_A_CONTENTS = yaml.dump({"default": "role:fakeA"})
+POLICY_B_CONTENTS = yaml.dump({"default": "role:fakeB"})
+POLICY_FAKE_CONTENTS = yaml.dump({"default": "role:fakeC"})
+POLICY_YAML_CONTENTS = yaml.dump({
     "default": "rule:admin",
     "admin": "is_admin:True"
 })
@@ -55,8 +55,7 @@ class FieldCheck(_checks.Check):
         # Process the match
         resource, field_value = match.split(':', 1)
         field, value = field_value.split('=', 1)
-        super(FieldCheck, self).__init__(kind, '%s:%s:%s' %
-                                         (resource, field, value))
+        super().__init__(kind, '{}:{}:{}'.format(resource, field, value))
         self.field = field
         self.value = value
 
@@ -235,8 +234,8 @@ default: [
 class EnforcerTest(base.PolicyBaseTestCase):
 
     def setUp(self):
-        super(EnforcerTest, self).setUp()
-        self.create_config_file('policy.json', POLICY_JSON_CONTENTS)
+        super().setUp()
+        self.create_config_file('policy.yaml', POLICY_YAML_CONTENTS)
 
     def _test_scenario_with_opts_registered(self, scenario, *args, **kwargs):
         # This test registers some rules, calls the scenario and then checks
@@ -281,7 +280,7 @@ class EnforcerTest(base.PolicyBaseTestCase):
             os.path.join('policy.d', 'b.conf'), POLICY_B_CONTENTS)
         self.enforcer.load_rules(True)
         self.assertIsNotNone(self.enforcer.rules)
-        loaded_rules = jsonutils.loads(str(self.enforcer.rules))
+        loaded_rules = yaml.safe_load(str(self.enforcer.rules))
         self.assertEqual('role:fakeB', loaded_rules['default'])
         self.assertEqual('is_admin:True', loaded_rules['admin'])
 
@@ -290,19 +289,19 @@ class EnforcerTest(base.PolicyBaseTestCase):
             os.path.join('policy.d', 'a.conf'), POLICY_A_CONTENTS)
         self.enforcer.load_rules(True)
         self.assertIsNotNone(self.enforcer.rules)
-        loaded_rules = jsonutils.loads(str(self.enforcer.rules))
+        loaded_rules = yaml.safe_load(str(self.enforcer.rules))
         self.assertEqual('role:fakeA', loaded_rules['default'])
         self.assertEqual('is_admin:True', loaded_rules['admin'])
-        new_policy_json_contents = jsonutils.dumps({
+        new_policy_yaml_contents = yaml.dump({
             "default": "rule:admin",
             "admin": "is_admin:True",
             "foo": "rule:bar",
         })
-        # Modify the policy.json file and then validate that the rules
+        # Modify the policy.yaml file and then validate that the rules
         # from the policy directory are re-applied on top of the
         # new rules from the file.
-        self.create_config_file('policy.json', new_policy_json_contents)
-        policy_file_path = self.get_config_file_fullname('policy.json')
+        self.create_config_file('policy.yaml', new_policy_yaml_contents)
+        policy_file_path = self.get_config_file_fullname('policy.yaml')
         # Force the mtime change since the unit test may write to this file
         # too fast for mtime to actually change.
         stinfo = os.stat(policy_file_path)
@@ -312,7 +311,7 @@ class EnforcerTest(base.PolicyBaseTestCase):
         self.enforcer.load_rules()
 
         self.assertIsNotNone(self.enforcer.rules)
-        loaded_rules = jsonutils.loads(str(self.enforcer.rules))
+        loaded_rules = yaml.safe_load(str(self.enforcer.rules))
         self.assertEqual('role:fakeA', loaded_rules['default'])
         self.assertEqual('is_admin:True', loaded_rules['admin'])
         self.assertEqual('rule:bar', loaded_rules['foo'])
@@ -324,12 +323,12 @@ class EnforcerTest(base.PolicyBaseTestCase):
             :param enforcer_rules: enforcer rules represented as a class Rules
             :return: enforcer rules represented as a dictionary
             """
-            return jsonutils.loads(str(enforcer_rules))
+            return yaml.safe_load(str(enforcer_rules))
 
         self.assertEqual(self.enforcer.rules, {})
 
         self.enforcer.load_rules()
-        main_policy_file_rules = jsonutils.loads(POLICY_JSON_CONTENTS)
+        main_policy_file_rules = yaml.safe_load(POLICY_YAML_CONTENTS)
         self.assertEqual(main_policy_file_rules,
                          dict_rules(self.enforcer.rules))
 
@@ -337,7 +336,7 @@ class EnforcerTest(base.PolicyBaseTestCase):
         self.create_config_file(folder_policy_file, POLICY_A_CONTENTS)
         self.enforcer.load_rules()
         expected_rules = main_policy_file_rules.copy()
-        expected_rules.update(jsonutils.loads(POLICY_A_CONTENTS))
+        expected_rules.update(yaml.safe_load(POLICY_A_CONTENTS))
         self.assertEqual(expected_rules, dict_rules(self.enforcer.rules))
 
         self.create_config_file(folder_policy_file, '{}')
@@ -375,7 +374,7 @@ class EnforcerTest(base.PolicyBaseTestCase):
         self.assertEqual(1, len(self.enforcer._policy_dir_mtimes))
         self.assertEqual(old, next(iter(self.enforcer._policy_dir_mtimes)))
 
-        loaded_rules = jsonutils.loads(str(self.enforcer.rules))
+        loaded_rules = yaml.safe_load(str(self.enforcer.rules))
         self.assertEqual('is_admin:True', loaded_rules['admin'])
 
     def test_load_directory_caching_with_files_updated_opts_registered(self):
@@ -398,7 +397,7 @@ class EnforcerTest(base.PolicyBaseTestCase):
         self.assertEqual(1, len(self.enforcer._policy_dir_mtimes))
         self.assertEqual(old, next(iter(self.enforcer._policy_dir_mtimes)))
 
-        loaded_rules = jsonutils.loads(str(self.enforcer.rules))
+        loaded_rules = yaml.safe_load(str(self.enforcer.rules))
         self.assertEqual('is_admin:True', loaded_rules['admin'])
 
     def test_load_directory_caching_with_files_same_but_overwrite_false(self):
@@ -417,7 +416,9 @@ class EnforcerTest(base.PolicyBaseTestCase):
     @mock.patch.object(policy, 'LOG')
     def test_load_json_file_log_warning(self, mock_log):
         rules = jsonutils.dumps({'foo': 'rule:bar'})
-        self.create_config_file('policy.json', rules)
+        # NOTE(tkajinam): This is ugly but an easy way to make the enforcer
+        #                 load a JSON-formatted file.
+        self.create_config_file('policy.yaml', rules)
         self.enforcer.load_rules(True)
 
         mock_log.warning.assert_any_call(policy.WARN_JSON)
@@ -454,7 +455,7 @@ class EnforcerTest(base.PolicyBaseTestCase):
                                group='oslo_policy')
         self.enforcer.load_rules(True)
         self.assertIsNotNone(self.enforcer.rules)
-        loaded_rules = jsonutils.loads(str(self.enforcer.rules))
+        loaded_rules = yaml.safe_load(str(self.enforcer.rules))
         self.assertEqual('role:fakeC', loaded_rules['default'])
         self.assertEqual('is_admin:True', loaded_rules['admin'])
 
@@ -572,22 +573,22 @@ class EnforcerTest(base.PolicyBaseTestCase):
         self.assertEqual({}, self.enforcer.registered_rules)
 
     def test_rule_with_check(self):
-        rules_json = jsonutils.dumps({
+        rules_yaml = yaml.dump({
             "deny_stack_user": "not role:stack_user",
             "cloudwatch:PutMetricData": ""
         })
-        rules = policy.Rules.load(rules_json)
+        rules = policy.Rules.load(rules_yaml)
         self.enforcer.set_rules(rules)
         action = 'cloudwatch:PutMetricData'
         creds = {'roles': ''}
         self.assertTrue(self.enforcer.enforce(action, {}, creds))
 
     def test_enforcer_with_default_rule(self):
-        rules_json = jsonutils.dumps({
+        rules_yaml = yaml.dump({
             "deny_stack_user": "not role:stack_user",
             "cloudwatch:PutMetricData": ""
         })
-        rules = policy.Rules.load(rules_json)
+        rules = policy.Rules.load(rules_yaml)
         default_rule = _checks.TrueCheck()
         enforcer = policy.Enforcer(self.conf, default_rule=default_rule)
         enforcer.set_rules(rules)
@@ -623,7 +624,7 @@ class EnforcerTest(base.PolicyBaseTestCase):
         self.assertNotIn('test', self.enforcer.rules)
         self.assertIn('default', self.enforcer.rules)
         self.assertIn('admin', self.enforcer.rules)
-        loaded_rules = jsonutils.loads(str(self.enforcer.rules))
+        loaded_rules = yaml.safe_load(str(self.enforcer.rules))
         self.assertEqual(2 + opts_registered, len(loaded_rules))
         self.assertIn('role:fakeB', loaded_rules['default'])
         self.assertIn('is_admin:True', loaded_rules['admin'])
@@ -663,7 +664,7 @@ class EnforcerTest(base.PolicyBaseTestCase):
         self.assertIn('test', self.enforcer.rules)
         self.assertIn('default', self.enforcer.rules)
         self.assertIn('admin', self.enforcer.rules)
-        loaded_rules = jsonutils.loads(str(self.enforcer.rules))
+        loaded_rules = yaml.safe_load(str(self.enforcer.rules))
         self.assertEqual(3 + opts_registered, len(loaded_rules))
         self.assertIn('role:test', loaded_rules['test'])
         self.assertIn('role:fakeB', loaded_rules['default'])
@@ -694,11 +695,11 @@ class EnforcerTest(base.PolicyBaseTestCase):
         # reloading will be triggered when calling
         # enforcer(), this case could happen only
         # when use_conf flag equals True.
-        rules = jsonutils.loads(str(self.enforcer.rules))
+        rules = yaml.safe_load(str(self.enforcer.rules))
         rules['_dynamic_test_rule'] = 'role:test'
 
         with open(self.enforcer.policy_path, 'w') as f:
-            f.write(jsonutils.dumps(rules))
+            f.write(yaml.dump(rules))
 
         self.enforcer.load_rules(force_reload=True)
         self.assertTrue(self.enforcer.enforce('_dynamic_test_rule', {},
@@ -747,14 +748,14 @@ class EnforcerTest(base.PolicyBaseTestCase):
                          enforcer.policy_file)
 
     def test_enforcer_with_policy_file(self):
-        enforcer = policy.Enforcer(self.conf, policy_file='non-default.json')
-        self.assertEqual('non-default.json', enforcer.policy_file)
+        enforcer = policy.Enforcer(self.conf, policy_file='non-default.yaml')
+        self.assertEqual('non-default.yaml', enforcer.policy_file)
 
     def test_get_policy_path_raises_exc(self):
-        enforcer = policy.Enforcer(self.conf, policy_file='raise_error.json')
+        enforcer = policy.Enforcer(self.conf, policy_file='raise_error.yaml')
         e = self.assertRaises(cfg.ConfigFilesNotFoundError,
                               enforcer._get_policy_path, enforcer.policy_file)
-        self.assertEqual(('raise_error.json', ), e.config_files)
+        self.assertEqual(('raise_error.yaml', ), e.config_files)
 
     def test_enforcer_set_rules(self):
         self.enforcer.load_rules()
@@ -797,13 +798,13 @@ class EnforcerTest(base.PolicyBaseTestCase):
         self.assertEqual(rule_original.check.__str__(), 'role:owner')
 
     def test_non_reversible_check(self):
-        self.create_config_file('policy.json',
-                                jsonutils.dumps(
+        self.create_config_file('policy.yaml',
+                                yaml.dump(
                                     {'shared': 'field:networks:shared=True'}))
         # load_rules succeeding without error is the focus of this test
         self.enforcer.load_rules(True)
         self.assertIsNotNone(self.enforcer.rules)
-        loaded_rules = jsonutils.loads(str(self.enforcer.rules))
+        loaded_rules = yaml.safe_load(str(self.enforcer.rules))
         self.assertNotEqual('field:networks:shared=True',
                             loaded_rules['shared'])
 
@@ -841,7 +842,7 @@ class EnforcerTest(base.PolicyBaseTestCase):
         rule = policy.RuleDefault(name='fake_rule', check_str='role:test')
         self.enforcer.register_default(rule)
 
-        class InvalidContext(object):
+        class InvalidContext:
             pass
 
         request_context = InvalidContext()
@@ -1045,7 +1046,7 @@ class EnforcerTest(base.PolicyBaseTestCase):
 
 class EnforcerNoPolicyFileTest(base.PolicyBaseTestCase):
     def setUp(self):
-        super(EnforcerNoPolicyFileTest, self).setUp()
+        super().setUp()
 
     def test_load_rules(self):
         # Check that loading rules with no policy file does not error
@@ -1065,11 +1066,11 @@ class EnforcerNoPolicyFileTest(base.PolicyBaseTestCase):
         self.assertEqual('is_admin:False', str(self.enforcer.rules['admin']))
 
     def test_load_directory(self):
-        self.create_config_file('policy.d/a.conf', POLICY_JSON_CONTENTS)
+        self.create_config_file('policy.d/a.conf', POLICY_YAML_CONTENTS)
         self.create_config_file('policy.d/b.conf', POLICY_B_CONTENTS)
         self.enforcer.load_rules(True)
         self.assertIsNotNone(self.enforcer.rules)
-        loaded_rules = jsonutils.loads(str(self.enforcer.rules))
+        loaded_rules = yaml.safe_load(str(self.enforcer.rules))
         self.assertEqual('role:fakeB', loaded_rules['default'])
         self.assertEqual('is_admin:True', loaded_rules['admin'])
 
@@ -1077,8 +1078,8 @@ class EnforcerNoPolicyFileTest(base.PolicyBaseTestCase):
 class CheckFunctionTestCase(base.PolicyBaseTestCase):
 
     def setUp(self):
-        super(CheckFunctionTestCase, self).setUp()
-        self.create_config_file('policy.json', POLICY_JSON_CONTENTS)
+        super().setUp()
+        self.create_config_file('policy.yaml', POLICY_YAML_CONTENTS)
 
     def test_check_explicit(self):
         rule = base.FakeCheck()
@@ -1087,8 +1088,8 @@ class CheckFunctionTestCase(base.PolicyBaseTestCase):
         self.assertEqual(('target', creds, self.enforcer), result)
 
     def test_check_no_rules(self):
-        # Clear the policy.json file created in setUp()
-        self.create_config_file('policy.json', "{}")
+        # Clear the policy.yaml file created in setUp()
+        self.create_config_file('policy.yaml', "{}")
         self.enforcer.default_rule = None
         self.enforcer.load_rules()
         creds = {}
@@ -1106,7 +1107,7 @@ class CheckFunctionTestCase(base.PolicyBaseTestCase):
         # If the rule doesn't exist, then enforce() fails rather than KeyError.
 
         # This test needs a non-empty file otherwise the code short-circuits.
-        self.create_config_file('policy.json', jsonutils.dumps({"a_rule": []}))
+        self.create_config_file('policy.yaml', yaml.dump({"a_rule": []}))
         self.enforcer.default_rule = None
         self.enforcer.load_rules()
         creds = {}
@@ -1207,7 +1208,7 @@ class RuleDefaultTestCase(base.PolicyBaseTestCase):
         self.assertNotEqual(opt1, opt2)
 
     def test_not_equal_class(self):
-        class NotRuleDefault(object):
+        class NotRuleDefault:
             def __init__(self, name, check_str):
                 self.name = name
                 self.check = _parser.parse_rule(check_str)
@@ -1271,7 +1272,6 @@ class RuleDefaultTestCase(base.PolicyBaseTestCase):
 
 class DocumentedRuleDefaultDeprecationTestCase(base.PolicyBaseTestCase):
 
-    @mock.patch('warnings.warn', new=mock.Mock())
     def test_deprecate_a_policy_check_string(self):
         deprecated_rule = policy.DeprecatedRule(
             name='foo:create_bar',
@@ -1285,33 +1285,24 @@ class DocumentedRuleDefaultDeprecationTestCase(base.PolicyBaseTestCase):
             check_str='role:bang',
             description='Create a bar.',
             operations=[{'path': '/v1/bars', 'method': 'POST'}],
+            scope_types=['project'],
             deprecated_rule=deprecated_rule,
         )]
         enforcer = policy.Enforcer(self.conf)
         enforcer.register_defaults(rule_list)
-        expected_msg = (
-            'Policy "foo:create_bar":"role:fizz" was deprecated in N in favor '
-            'of "foo:create_bar":"role:bang". Reason: "role:bang" is a better '
-            'default. Either ensure your deployment is ready for the new '
-            'default or copy/paste the deprecated policy into your policy '
-            'file and maintain it manually.'
-        )
 
-        with mock.patch('warnings.warn') as mock_warn:
-            enforcer.load_rules()
-            mock_warn.assert_called_once_with(expected_msg)
+        enforcer.load_rules()
 
         self.assertTrue(
             enforcer.enforce('foo:create_bar', {}, {'roles': ['bang']})
         )
-        self.assertTrue(
+        self.assertFalse(
             enforcer.enforce('foo:create_bar', {}, {'roles': ['fizz']})
         )
         self.assertFalse(
             enforcer.enforce('foo:create_bar', {}, {'roles': ['baz']})
         )
 
-    @mock.patch('warnings.warn', new=mock.Mock())
     def test_deprecate_an_empty_policy_check_string(self):
         deprecated_rule = policy.DeprecatedRule(
             name='foo:create_bar',
@@ -1325,21 +1316,18 @@ class DocumentedRuleDefaultDeprecationTestCase(base.PolicyBaseTestCase):
             check_str='role:bang',
             description='Create a bar.',
             operations=[{'path': '/v1/bars', 'method': 'POST'}],
+            scope_types=['project'],
             deprecated_rule=deprecated_rule,
         )]
         enforcer = policy.Enforcer(self.conf)
         enforcer.register_defaults(rule_list)
-
-        with mock.patch('warnings.warn') as mock_warn:
-            enforcer.load_rules()
-            mock_warn.assert_called_once()
+        enforcer.load_rules()
 
         enforcer.enforce('foo:create_bar', {}, {'roles': ['bang']},
                          do_raise=True)
-        enforcer.enforce('foo:create_bar', {}, {'roles': ['fizz']},
-                         do_raise=True)
+        self.assertFalse(
+            self.enforcer.enforce('foo:create_bar', {}, {'roles': ['fizz']}))
 
-    @mock.patch('warnings.warn', new=mock.Mock())
     def test_deprecate_replace_with_empty_policy_check_string(self):
         deprecated_rule = policy.DeprecatedRule(
             name='foo:create_bar',
@@ -1353,14 +1341,12 @@ class DocumentedRuleDefaultDeprecationTestCase(base.PolicyBaseTestCase):
             check_str='',
             description='Create a bar.',
             operations=[{'path': '/v1/bars', 'method': 'POST'}],
+            scope_types=['project'],
             deprecated_rule=deprecated_rule,
         )]
         enforcer = policy.Enforcer(self.conf)
         enforcer.register_defaults(rule_list)
-
-        with mock.patch('warnings.warn') as mock_warn:
-            enforcer.load_rules()
-            mock_warn.assert_called_once()
+        enforcer.load_rules()
 
         enforcer.enforce('foo:create_bar', {}, {'roles': ['fizz']},
                          do_raise=True)
@@ -1387,6 +1373,7 @@ class DocumentedRuleDefaultDeprecationTestCase(base.PolicyBaseTestCase):
             check_str='role:baz',
             description='Create a bar.',
             operations=[{'path': '/v1/bars/', 'method': 'POST'}],
+            scope_types=['project'],
             deprecated_rule=deprecated_rule,
         )]
         expected_msg = (
@@ -1402,8 +1389,8 @@ class DocumentedRuleDefaultDeprecationTestCase(base.PolicyBaseTestCase):
             'file and maintain it manually.'
         )
 
-        rules = jsonutils.dumps({'foo:bar': 'role:bang'})
-        self.create_config_file('policy.json', rules)
+        rules = yaml.dump({'foo:bar': 'role:bang'})
+        self.create_config_file('policy.yaml', rules)
         enforcer = policy.Enforcer(self.conf)
         enforcer.register_defaults(rule_list)
 
@@ -1428,8 +1415,8 @@ class DocumentedRuleDefaultDeprecationTestCase(base.PolicyBaseTestCase):
             'Reason: "foo:bar" is no longer a policy used by the service. Its '
             'value may be silently ignored in the future.'
         )
-        rules = jsonutils.dumps({'foo:bar': 'role:bang'})
-        self.create_config_file('policy.json', rules)
+        rules = yaml.dump({'foo:bar': 'role:bang'})
+        self.create_config_file('policy.yaml', rules)
         enforcer = policy.Enforcer(self.conf)
         enforcer.register_defaults(rule_list)
 
@@ -1459,6 +1446,8 @@ class DocumentedRuleDefaultDeprecationTestCase(base.PolicyBaseTestCase):
             mock_warn.assert_not_called()
 
     def test_deprecate_check_str_suppress_does_not_log_warning(self):
+        self.conf.set_override('enforce_new_defaults', False,
+                               group='oslo_policy')
         deprecated_rule = policy.DeprecatedRule(
             name='foo:create_bar',
             check_str='role:fizz',
@@ -1481,6 +1470,8 @@ class DocumentedRuleDefaultDeprecationTestCase(base.PolicyBaseTestCase):
             mock_warn.assert_not_called()
 
     def test_deprecate_name_suppress_does_not_log_warning(self):
+        self.conf.set_override('enforce_new_defaults', False,
+                               group='oslo_policy')
         deprecated_rule = policy.DeprecatedRule(
             name='foo:bar',
             check_str='role:baz',
@@ -1496,8 +1487,8 @@ class DocumentedRuleDefaultDeprecationTestCase(base.PolicyBaseTestCase):
             deprecated_rule=deprecated_rule,
         )]
 
-        rules = jsonutils.dumps({'foo:bar': 'role:bang'})
-        self.create_config_file('policy.json', rules)
+        rules = yaml.dump({'foo:bar': 'role:bang'})
+        self.create_config_file('policy.yaml', rules)
         enforcer = policy.Enforcer(self.conf)
         enforcer.suppress_deprecation_warnings = True
         enforcer.register_defaults(rule_list)
@@ -1507,6 +1498,9 @@ class DocumentedRuleDefaultDeprecationTestCase(base.PolicyBaseTestCase):
             mock_warn.assert_not_called()
 
     def test_deprecate_for_removal_suppress_does_not_log_warning(self):
+        self.conf.set_override('enforce_new_defaults', False,
+                               group='oslo_policy')
+
         rule_list = [policy.DocumentedRuleDefault(
             name='foo:bar',
             check_str='role:baz',
@@ -1518,8 +1512,8 @@ class DocumentedRuleDefaultDeprecationTestCase(base.PolicyBaseTestCase):
             ),
             deprecated_since='N'
         )]
-        rules = jsonutils.dumps({'foo:bar': 'role:bang'})
-        self.create_config_file('policy.json', rules)
+        rules = yaml.dump({'foo:bar': 'role:bang'})
+        self.create_config_file('policy.yaml', rules)
         enforcer = policy.Enforcer(self.conf)
         enforcer.suppress_deprecation_warnings = True
         enforcer.register_defaults(rule_list)
@@ -1529,6 +1523,9 @@ class DocumentedRuleDefaultDeprecationTestCase(base.PolicyBaseTestCase):
             mock_warn.assert_not_called()
 
     def test_suppress_default_change_warnings_flag_not_log_warning(self):
+        self.conf.set_override('enforce_new_defaults', False,
+                               group='oslo_policy')
+
         deprecated_rule = policy.DeprecatedRule(
             name='foo:create_bar',
             check_str='role:fizz',
@@ -1607,8 +1604,8 @@ class DocumentedRuleDefaultDeprecationTestCase(base.PolicyBaseTestCase):
     @mock.patch('warnings.warn', new=mock.Mock())
     def test_override_deprecated_policy_with_old_name(self):
         # Simulate an operator overriding a policy
-        rules = jsonutils.dumps({'foo:bar': 'role:bazz'})
-        self.create_config_file('policy.json', rules)
+        rules = yaml.dump({'foo:bar': 'role:bazz'})
+        self.create_config_file('policy.yaml', rules)
 
         # Deprecate the policy name and check string in favor of something
         # better.
@@ -1641,8 +1638,8 @@ class DocumentedRuleDefaultDeprecationTestCase(base.PolicyBaseTestCase):
 
     def test_override_deprecated_policy_with_new_name(self):
         # Simulate an operator overriding a policy using the new policy name
-        rules = jsonutils.dumps({'foo:create_bar': 'role:bazz'})
-        self.create_config_file('policy.json', rules)
+        rules = yaml.dump({'foo:create_bar': 'role:bazz'})
+        self.create_config_file('policy.yaml', rules)
 
         # Deprecate the policy name and check string in favor of something
         # better.
@@ -1683,8 +1680,8 @@ class DocumentedRuleDefaultDeprecationTestCase(base.PolicyBaseTestCase):
             'foo:create_bar': 'role:bazz',
             'foo:bar': 'role:wee'
         }
-        rules = jsonutils.dumps(rules_dict)
-        self.create_config_file('policy.json', rules)
+        rules = yaml.dump(rules_dict)
+        self.create_config_file('policy.yaml', rules)
 
         # Deprecate the policy name and check string in favor of something
         # better.
@@ -1728,8 +1725,8 @@ class DocumentedRuleDefaultDeprecationTestCase(base.PolicyBaseTestCase):
     def test_override_deprecated_policy_with_new_rule(self):
         # Simulate an operator overriding a deprecated policy with a reference
         # to the new policy, as done by the sample policy generator.
-        rules = jsonutils.dumps({'old_rule': 'rule:new_rule'})
-        self.create_config_file('policy.json', rules)
+        rules = yaml.dump({'old_rule': 'rule:new_rule'})
+        self.create_config_file('policy.yaml', rules)
 
         # Deprecate the policy name in favor of something better.
         deprecated_rule = policy.DeprecatedRule(
@@ -1759,8 +1756,6 @@ class DocumentedRuleDefaultDeprecationTestCase(base.PolicyBaseTestCase):
         self.assertEqual('bang', self.enforcer.rules['new_rule'].match)
 
     def test_enforce_new_defaults_no_old_check_string(self):
-        self.conf.set_override('enforce_new_defaults', True,
-                               group='oslo_policy')
         deprecated_rule = policy.DeprecatedRule(
             name='foo:create_bar',
             check_str='role:fizz',
@@ -1791,6 +1786,43 @@ class DocumentedRuleDefaultDeprecationTestCase(base.PolicyBaseTestCase):
             enforcer.enforce('foo:create_bar', {}, {'roles': ['baz']})
         )
 
+    def test_disable_enforce_new_defaults_add_old_check_string(self):
+        self.conf.set_override('enforce_new_defaults', False,
+                               group='oslo_policy')
+        deprecated_rule = policy.DeprecatedRule(
+            name='foo:create_bar',
+            check_str='role:fizz',
+            deprecated_reason='"role:bang" is a better default',
+            deprecated_since='N',
+        )
+
+        rule_list = [policy.DocumentedRuleDefault(
+            name='foo:create_bar',
+            check_str='role:bang',
+            description='Create a bar.',
+            operations=[{'path': '/v1/bars', 'method': 'POST'}],
+            deprecated_rule=deprecated_rule,
+        )]
+        enforcer = policy.Enforcer(self.conf)
+        enforcer.register_defaults(rule_list)
+        enforcer.load_rules()
+
+        expected_check = policy.OrCheck([
+            _parser.parse_rule(cs) for cs in
+            [rule_list[0].check_str, deprecated_rule.check_str]
+        ])
+        self.assertEqual(
+            str(enforcer.rules['foo:create_bar']), str(expected_check))
+        self.assertTrue(
+            enforcer.enforce('foo:create_bar', {}, {'roles': ['bang']})
+        )
+        self.assertTrue(
+            enforcer.enforce('foo:create_bar', {}, {'roles': ['fizz']})
+        )
+        self.assertFalse(
+            enforcer.enforce('foo:create_bar', {}, {'roles': ['baz']})
+        )
+
     def test_deprecation_logic_is_only_performed_once_per_rule(self):
         deprecated_rule = policy.DeprecatedRule(
             name='foo:create_bar',
@@ -1817,15 +1849,12 @@ class DocumentedRuleDefaultDeprecationTestCase(base.PolicyBaseTestCase):
         enforcer.load_rules()
 
         # Loading the rules will store a version of the rule check string
-        # logically ORed with the check string of the deprecated value. Make
-        # sure this is happening but that the original rule check is unchanged
-        expected_check = policy.OrCheck([
-            _parser.parse_rule(cs) for cs in
-            [rule.check_str, deprecated_rule.check_str]
-        ])
+        # but as enforce_new_defaults is True it will not logically ORed with
+        # the check string of the deprecated value. Make sure this is happening
+        # and the original rule check is unchanged
         self.assertIn('foo:create_bar', enforcer.rules)
-        self.assertEqual(
-            str(enforcer.rules['foo:create_bar']), str(expected_check))
+        self.assertEqual(rule.check_str,
+                         str(enforcer.rules['foo:create_bar']))
         self.assertEqual(check, rule.check)
         # Hacky way to check whether _handle_deprecated_rule was called again.
         # If a second call to load_rules doesn't overwrite our dummy rule then
@@ -1932,36 +1961,56 @@ class DeprecatedRuleTestCase(base.PolicyBaseTestCase):
 
 class EnforcerCheckRulesTest(base.PolicyBaseTestCase):
     def setUp(self):
-        super(EnforcerCheckRulesTest, self).setUp()
+        super().setUp()
 
     def test_no_violations(self):
-        self.create_config_file('policy.json', POLICY_JSON_CONTENTS)
+        self.create_config_file('policy.yaml', POLICY_YAML_CONTENTS)
         self.enforcer.load_rules(True)
         self.assertTrue(self.enforcer.check_rules(raise_on_violation=True))
 
     @mock.patch.object(policy, 'LOG')
     def test_undefined_rule(self, mock_log):
-        rules = jsonutils.dumps({'foo': 'rule:bar'})
-        self.create_config_file('policy.json', rules)
+        rules = yaml.dump({'foo': 'rule:bar'})
+        self.create_config_file('policy.yaml', rules)
         self.enforcer.load_rules(True)
 
         self.assertFalse(self.enforcer.check_rules())
         mock_log.warning.assert_called()
 
+    @mock.patch.object(policy, 'LOG')
+    def test_undefined_rule_skipped(self, mock_log):
+        rules = yaml.dump({'foo': 'rule:bar'})
+        self.create_config_file('policy.yaml', rules)
+        self.enforcer.skip_undefined_check = True
+        self.enforcer.load_rules(True)
+
+        self.assertTrue(self.enforcer.check_rules())
+        mock_log.warning.assert_not_called()
+
     @mock.patch.object(policy, 'LOG')
     def test_undefined_rule_raises(self, mock_log):
-        rules = jsonutils.dumps({'foo': 'rule:bar'})
-        self.create_config_file('policy.json', rules)
+        rules = yaml.dump({'foo': 'rule:bar'})
+        self.create_config_file('policy.yaml', rules)
         self.enforcer.load_rules(True)
 
         self.assertRaises(policy.InvalidDefinitionError,
                           self.enforcer.check_rules, raise_on_violation=True)
         mock_log.warning.assert_called()
 
+    @mock.patch.object(policy, 'LOG')
+    def test_undefined_rule_raises_skipped(self, mock_log):
+        rules = yaml.dump({'foo': 'rule:bar'})
+        self.create_config_file('policy.yaml', rules)
+        self.enforcer.skip_undefined_check = True
+        self.enforcer.load_rules(True)
+
+        self.assertTrue(self.enforcer.check_rules(raise_on_violation=True))
+        mock_log.warning.assert_not_called()
+
     @mock.patch.object(policy, 'LOG')
     def test_cyclical_rules(self, mock_log):
-        rules = jsonutils.dumps({'foo': 'rule:bar', 'bar': 'rule:foo'})
-        self.create_config_file('policy.json', rules)
+        rules = yaml.dump({'foo': 'rule:bar', 'bar': 'rule:foo'})
+        self.create_config_file('policy.yaml', rules)
         self.enforcer.load_rules(True)
 
         self.assertFalse(self.enforcer.check_rules())
@@ -1969,8 +2018,8 @@ class EnforcerCheckRulesTest(base.PolicyBaseTestCase):
 
     @mock.patch.object(policy, 'LOG')
     def test_cyclical_rules_raises(self, mock_log):
-        rules = jsonutils.dumps({'foo': 'rule:bar', 'bar': 'rule:foo'})
-        self.create_config_file('policy.json', rules)
+        rules = yaml.dump({'foo': 'rule:bar', 'bar': 'rule:foo'})
+        self.create_config_file('policy.yaml', rules)
         self.enforcer.load_rules(True)
 
         self.assertRaises(policy.InvalidDefinitionError,
@@ -1979,20 +2028,20 @@ class EnforcerCheckRulesTest(base.PolicyBaseTestCase):
 
     @mock.patch.object(policy, 'LOG')
     def test_complex_cyclical_rules_false(self, mock_log):
-        rules = jsonutils.dumps({'foo': 'rule:bar',
-                                 'bar': 'rule:baz and role:admin',
-                                 'baz': 'rule:foo or role:user'})
-        self.create_config_file('policy.json', rules)
+        rules = yaml.dump({'foo': 'rule:bar',
+                           'bar': 'rule:baz and role:admin',
+                           'baz': 'rule:foo or role:user'})
+        self.create_config_file('policy.yaml', rules)
         self.enforcer.load_rules(True)
 
         self.assertFalse(self.enforcer.check_rules())
         mock_log.warning.assert_called()
 
     def test_complex_cyclical_rules_true(self):
-        rules = jsonutils.dumps({'foo': 'rule:bar or rule:baz',
-                                 'bar': 'role:admin',
-                                 'baz': 'rule:bar or role:user'})
-        self.create_config_file('policy.json', rules)
+        rules = yaml.dump({'foo': 'rule:bar or rule:baz',
+                           'bar': 'role:admin',
+                           'baz': 'rule:bar or role:user'})
+        self.create_config_file('policy.yaml', rules)
         self.enforcer.load_rules(True)
 
         self.assertTrue(self.enforcer.check_rules())
@@ -2001,7 +2050,7 @@ class EnforcerCheckRulesTest(base.PolicyBaseTestCase):
 class PickPolicyFileTestCase(base.PolicyBaseTestCase):
 
     def setUp(self):
-        super(PickPolicyFileTestCase, self).setUp()
+        super().setUp()
         self.data = {
             'rule_admin': 'True',
             'rule_admin2': 'is_admin:True'
@@ -2042,8 +2091,6 @@ class PickPolicyFileTestCase(base.PolicyBaseTestCase):
         self.assertEqual(selected_policy_file, tmpfilename)
 
     def test_only_new_default_policy_file_exist(self):
-        self.conf.set_override('policy_file', 'policy.yaml',
-                               group='oslo_policy')
         tmpfilename = os.path.join(self.tmpdir.path, 'policy.yaml')
         with open(tmpfilename, 'w') as fh:
             yaml.dump(self.data, fh)
@@ -2053,8 +2100,6 @@ class PickPolicyFileTestCase(base.PolicyBaseTestCase):
         self.assertEqual(selected_policy_file, 'policy.yaml')
 
     def test_only_old_default_policy_file_exist(self):
-        self.conf.set_override('policy_file', 'policy.yaml',
-                               group='oslo_policy')
         tmpfilename = os.path.join(self.tmpdir.path, 'policy.json')
         with open(tmpfilename, 'w') as fh:
             jsonutils.dump(self.data, fh)
@@ -2064,8 +2109,6 @@ class PickPolicyFileTestCase(base.PolicyBaseTestCase):
         self.assertEqual(selected_policy_file, 'policy.json')
 
     def test_both_default_policy_file_exist(self):
-        self.conf.set_override('policy_file', 'policy.yaml',
-                               group='oslo_policy')
         tmpfilename1 = os.path.join(self.tmpdir.path, 'policy.json')
         with open(tmpfilename1, 'w') as fh:
             jsonutils.dump(self.data, fh)
